@@ -6,6 +6,9 @@
 	listdlg.h
 */
 
+#ifndef LISTDLG_H 
+#define LISTDLG_H 
+
 // QT
 #include <qdialog.h>
 #include <qlabel.h>
@@ -16,9 +19,13 @@
 #include <qpushbt.h>
 #include <qlined.h>
 #include <qfileinf.h>
+#include <qimage.h>
 
 // KDE
 #include <kapp.h>
+#include <kfileinfo.h>
+#include <kfiledialog.h>
+#include <kmsgbox.h> 
 
 class ListDialog : public QDialog {
 
@@ -29,12 +36,23 @@ public:
 	~ListDialog() {};	
 
 	void setEntryNum( int );
+	QStrList getNewList() const;
+	int getSelectNum() const;
 
 private slots:
 	void selectEntry( int );
+	void pressOk();
+	void pressBtA();
+	void pressBtB();
+	void pressBtC();
+	void pressBtD();
+	void addFileUrl();
 
 private:
+	bool		changeList;
 	QStrList	liste;
+	QString		fileUrl;
+	
 	QPushButton	*a_bt, *b_bt, *c_bt, *d_bt;
 	QPushButton	*ok_bt;
 	QLabel		*fenster;
@@ -42,3 +60,4 @@ private:
 	QLineEdit	*ph_box;
 };
 
+#endif // LISTDLG_H 
