@@ -6,13 +6,18 @@
 	pixview.h
 */
 
-#include <qlabel.h>
-#include <qpixmap.h>
+#ifndef PIXVIEW_H 
+#define PIXVIEW_H 
+
+// QT
 #include <qwmatrix.h>
-#include <qpopmenu.h>
-#include <qpmcache.h>
 #include <qpainter.h>
 #include <qpen.h>
+#include <qaccel.h>
+
+// KDE
+#include <kapp.h>
+#include <kmsgbox.h>
 
 class PixView : public QLabel
 {
@@ -22,13 +27,18 @@ private:
 	QPopupMenu	*popmenu; 
 	QPixmap		*copyimage;
 	QPixmap	 	*image;
+	QAccel		*keyset;
 	int		startx, starty;
 	int		oldx, oldy;
 	bool		draw;
 
+private slots:
+	void pressKey( int );
+
 public:
 	PixView(QWidget *parent=0, const char *name=0, WFlags f = 0);
 	bool load(const char *filename);
+	bool clear();
 
 public slots:	
 	void restoreImage();
@@ -44,3 +54,4 @@ protected:
 	void mouseReleaseEvent( QMouseEvent * );
 };
 
+#endif // PIXVIEW_H 
